# ALLCools

[![Tests](https://img.shields.io/github/workflow/status/lhqing/allcools/Test/main)](https://github.com/lhqing/allcools/actions/workflows/test.yml)
[![Jupyter Book Badge](https://jupyterbook.org/badge.svg)](https://lhqing.github.io/ALLCools/intro.html)

Please see [documentation](https://lhqing.github.io/ALLCools/intro.html).
